<?php
	require_once(dirname(__FILE__) . '/classes/GSBaseClass.php');
	require_once(dirname(__FILE__) . '/classes/GSAuth.php');
	require_once(dirname(__FILE__) . '/classes/GSUsers.php');
	require_once(dirname(__FILE__) . '/classes/GSUtils.php');

	class GSException extends Exception {}

	class GS {
		private $auth_key = NULL;
		private $auth_username = NULL;
		private $auth_password = NULL;

		protected $url = '';
		protected $curl = NULL;

		protected $api_version = '1.0';

		/**
		 * @var null|GSAuth
		 */
		private $auth_obj = NULL;

		/**
		 * @var null|GSUsers
		 */
		private $users_obj = NULL;

		/**
		 * @var null|GSUtils
		 */
		private $utils_obj = NULL;

		public function __construct($options) {
			if (array_key_exists("auth_key", $options)) {
				$this->setAuthKey($options['auth_key']);
			}
			if (array_key_exists("auth_username", $options)) {
				$this->setAuthUsername($options['auth_username']);
			}
			if (array_key_exists("auth_password", $options)) {
				$this->setAuthPassword($options['auth_password']);
			}
			if (array_key_exists("url", $options)) {
				$this->setUrl($options['url']);
			}
		}

		protected function getAuthKey() {
			return $this->auth_key;
		}

		public function setAuthKey($key) {
			$this->auth_key = $key;

			return $this;
		}

		public function getAuthUsername() {
			return $this->auth_username;
		}

		public function setAuthUsername($username) {
			$this->auth_username = $username;

			return $this;
		}

		public function getAuthPassword() {
			return $this->auth_password;
		}

		public function setAuthPassword($password) {
			$this->auth_password = $password;

			return $this;
		}

		public function getUrl() {
			return $this->url;
		}

		public function setUrl($url) {
			$this->url = $url;

			return $this;
		}

		public function getApiVersion() {
			return $this->api_version;
		}

		public function setApiVersion($version) {
			$this->api_version = $version;

			return $this;
		}

		public function auth() {
			if ($this->auth_obj == NULL) {
				$this->auth_obj = new GSAuth($this);
			}

			return $this->auth_obj;
		}

		public function users() {
			if ($this->users_obj == NULL) {
				$this->users_obj = new GSUsers($this);
			}

			return $this->users_obj;
		}

		public function utils() {
			if ($this->utils_obj == NULL) {
				$this->utils_obj = new GSUtils($this);
			}

			return $this->utils_obj;
		}
	}
?>